==> pipewire-docs-1%3A0.3.32-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/structstream.js <==
var structstream =
[
    [ "allow_mlock", "structstream.html#acfe5ed66bf6536300e724a6649ba5a62", null ],
    [ "base_pos", "structstream.html#a44a13a68b47b97b3bef41f3e801d09e6", null ],
    [ "buffers", "structstream.html#a5dad5c71aca03c94d3bf873b9f575c58", null ],
    [ "callbacks", "structstream.html#a2a4b596a8fd6684e563544921631bfde", null ],
    [ "change_mask_all", "structstream.html#a2afd916c12d7d91bddd23b30f709c582", null ],
    [ "clock_id", "structstream.html#a5e13d0a14c7715023a92ea6e5d1b603e", null ],
    [ "context", "structstream.html#a9de6d02605037e6dfe335552c2e398a3", null ],
    [ "context_listener", "structstream.html#a669c175165bd2b3898f2a02d37ac2819", null ],
    [ "data", "structstream.html#a53964295d5a2b27dd8a2eead24f3dfd6", null ],
    [ "dequeued", "structstream.html#a369dbaa5cdda9aad66fc4ee6af6cc911", null ],
    [ "direction", "structstream.html#a386c312c7ee7ec6ad015165614514b6f", null ],
    [ "disconnect_core", "structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8", null ],
    [ "disconnecting", "structstream.html#a5e861c5f495c43750eda66e177a1b9c3", null ],
    [ "drained", "structstream.html#a0b67dcf51974d8cf6b73151658d42be3", null ],
    [ "draining", "structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19", null ],
    [ "flags", "structstream.html#a41be007c6de999aff0def3e6bb0e1652", null ],
    [ "hooks", "structstream.html#af472f42f40a7c7bb801fe844e228aed6", null ],
    [ "impl_node", "structstream.html#a33ef55c30dba3f533ce558a3a8918d6c", null ],
    [ "info", "structstream.html#aad7cad8506be0febb644b32bc68fc080", null ],
    [ "io", "structstream.html#ac744f31dcf0b62846bd67d2a525834f7", null ],
    [ "latency", "structstream.html#a6f1d484d6497b7cb7c46340b7a401203", null ],
    [ "media_subtype", "structstream.html#a62e63fe261a3eabe917744e31fb542bd", null ],
    [ "media_type", "structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd", null ],
    [ "n_buffers", "structstream.html#a8d11046e448d4132d6f54070efc1a34f", null ],
    [ "node", "structstream.html#a92c53f2e6b9f65b88dfef92d4d6db996", null ],
    [ "node_methods", "structstream.html#a5748defaf6f10586b00f8cd66aea87f2", null ],
    [ "param_list", "structstream.html#a9c0baf86f50f5b3961b0f12803108c0f", null ],
    [ "params", "structstream.html#adf023fb71007479a30b0b511322d4d51", null ],
    [ "path", "structstream.html#abdd59e087d05441c1ce0cdad1b2e2db6", null ],
    [ "port_change_mask_all", "structstream.html#aeefc1adbe864215977455c360bc8dd4f", null ],
    [ "port_info", "structstream.html#a0d379de7ce670bca527a67104d3a2ffc", null ],
    [ "port_params", "structstream.html#a3dc19ef9e886b257d24d43f15a8f6a8f", null ],
    [ "port_props", "structstream.html#a40880651364a231150d4d616b1bcea45", null ],
    [ "position", "structstream.html#a23cb7ea3db9d2b68df60709b71ee522c", null ],
    [ "process_rt", "structstream.html#a6fbe7e913ff0273df637ac36bdd3c1ff", null ],
    [ "quantum", "structstream.html#a0d1ac2ef60a390bb1eec188191a72c63", null ],
    [ "queued", "structstream.html#a3893af848bb4d21b0868f98fa7b79718", null ],
    [ "rt", "structstream.html#a8d83d64c0a423d59c8e42fd6bf22d286", null ],
    [ "rt_callbacks", "structstream.html#a4e6c8d10fa13e2b8dbd9f976f78bfbb0", null ],
    [ "seq", "structstream.html#a205abb8810d099ecd79ff9afd7931428", null ],
    [ "this", "structstream.html#a00d21063b64b6339d257433d02a0d5bc", null ],
    [ "time", "structstream.html#abc4bd0629266976bb016a722584ed09c", null ],
    [ "warn_mlock", "structstream.html#a1000143671503ec1a7a1a0ddad5a0b5b", null ]
];

==> pipewire-docs-1%3A0.3.33-1-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/structstream.js <==
var structstream =
[
    [ "active", "structstream.html#ae0349d38897dd88ecb7d01ebec8c2786", null ],
    [ "allow_mlock", "structstream.html#acfe5ed66bf6536300e724a6649ba5a62", null ],
    [ "base_pos", "structstream.html#a44a13a68b47b97b3bef41f3e801d09e6", null ],
    [ "buffers", "structstream.html#a5dad5c71aca03c94d3bf873b9f575c58", null ],
    [ "callbacks", "structstream.html#a2a4b596a8fd6684e563544921631bfde", null ],
    [ "change_mask_all", "structstream.html#a2afd916c12d7d91bddd23b30f709c582", null ],
    [ "clock_id", "structstream.html#a5e13d0a14c7715023a92ea6e5d1b603e", null ],
    [ "context", "structstream.html#a9de6d02605037e6dfe335552c2e398a3", null ],
    [ "context_listener", "structstream.html#a669c175165bd2b3898f2a02d37ac2819", null ],
    [ "data", "structstream.html#a53964295d5a2b27dd8a2eead24f3dfd6", null ],
    [ "dequeued", "structstream.html#a369dbaa5cdda9aad66fc4ee6af6cc911", null ],
    [ "direction", "structstream.html#a386c312c7ee7ec6ad015165614514b6f", null ],
    [ "disconnect_core", "structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8", null ],
    [ "disconnecting", "structstream.html#a5e861c5f495c43750eda66e177a1b9c3", null ],
    [ "drained", "structstream.html#a0b67dcf51974d8cf6b73151658d42be3", null ],
    [ "draining", "structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19", null ],
    [ "endpoint", "structstream.html#acd5a7c8dc94d1197352ab7e870ac8363", null ],
    [ "flags", "structstream.html#a41be007c6de999aff0def3e6bb0e1652", null ],
    [ "format", "structstream.html#aeb482c196ab95fae6b29d39932cd05ef", null ],
    [ "hooks", "structstream.html#af472f42f40a7c7bb801fe844e228aed6", null ],
    [ "id", "structstream.html#a977a401b2776163f2aa12f152f6c3387", null ],
    [ "impl", "structstream.html#ad61595beecdf4980fdeaf9e75ffa148d", null ],
    [ "impl_node", "structstream.html#a33ef55c30dba3f533ce558a3a8918d6c", null ],
    [ "info", "structstream.html#ac8f5f4c298a9ec6381dd89f330458489", null ],
    [ "info", "structstream.html#ac8f5f4c298a9ec6381dd89f330458489", null ],
    [ "io", "structstream.html#ac744f31dcf0b62846bd67d2a525834f7", null ],
    [ "key", "structstream.html#a0e1376d19b854172e7109e953f529fd6", null ],
    [ "latency", "structstream.html#a6f1d484d6497b7cb7c46340b7a401203", null ],
    [ "link", "structstream.html#a8865d6ed197fbe586713afb68b778a44", null ],
    [ "listener", "structstream.html#ae6be16db596a975cdc82122dd2328c0e", null ],
    [ "media_class", "structstream.html#a2e954630f2dfdf91a173fedfc59252b8", null ],
    [ "media_subtype", "structstream.html#a62e63fe261a3eabe917744e31fb542bd", null ],
    [ "media_type", "structstream.html#ac5c81fe4d3d48b283d1379d45b92cccd", null ],
    [ "n_buffers", "structstream.html#a8d11046e448d4132d6f54070efc1a34f", null ],
    [ "node", "structstream.html#a92c53f2e6b9f65b88dfef92d4d6db996", null ],
    [ "node_methods", "structstream.html#a5748defaf6f10586b00f8cd66aea87f2", null ],
    [ "obj", "structstream.html#a758e3ffaa9ab9503ec82f2a418ba665d", null ],
    [ "obj", "structstream.html#a97e9ee69e10647c032034631dca47cb5", null ],
    [ "param_list", "structstream.html#a9c0baf86f50f5b3961b0f12803108c0f", null ],
    [ "params", "structstream.html#adf023fb71007479a30b0b511322d4d51", null ],
    [ "path", "structstream.html#abdd59e087d05441c1ce0cdad1b2e2db6", null ],
    [ "port_change_mask_all", "structstream.html#aeefc1adbe864215977455c360bc8dd4f", null ],
    [ "port_info", "structstream.html#a0d379de7ce670bca527a67104d3a2ffc", null ],
    [ "port_params", "structstream.html#a3dc19ef9e886b257d24d43f15a8f6a8f", null ],
    [ "port_props", "structstream.html#a40880651364a231150d4d616b1bcea45", null ],
    [ "position", "structstream.html#a23cb7ea3db9d2b68df60709b71ee522c", null ],
    [ "process_rt", "structstream.html#a6fbe7e913ff0273df637ac36bdd3c1ff", null ],
    [ "props", "structstream.html#a3fd2c40938b37b4167550005f32bcb07", null ],
    [ "quantum", "structstream.html#a0d1ac2ef60a390bb1eec188191a72c63", null ],
    [ "queued", "structstream.html#a3893af848bb4d21b0868f98fa7b79718", null ],
    [ "restored", "structstream.html#a13237ed4183e2c26fec0534c401760af", null ],
    [ "rt", "structstream.html#a8d83d64c0a423d59c8e42fd6bf22d286", null ],
    [ "rt_callbacks", "structstream.html#a4e6c8d10fa13e2b8dbd9f976f78bfbb0", null ],
    [ "seq", "structstream.html#a205abb8810d099ecd79ff9afd7931428", null ],
    [ "this", "structstream.html#a00d21063b64b6339d257433d02a0d5bc", null ],
    [ "time", "structstream.html#abc4bd0629266976bb016a722584ed09c", null ],
    [ "warn_mlock", "structstream.html#a1000143671503ec1a7a1a0ddad5a0b5b", null ]
];
